@@ -27,37 +27,42 @@ import yaml
 from tripleo_common.image import base
 from tripleo_common.image import image_uploader
 
-CONTAINER_IMAGE_PREPARE_PARAM_STR = None
+CONTAINER_IMAGE_PREPARE_PARAM = [{
+    'tag_from_label': 'rdo_version',
+    'set': {
+        'namespace': 'docker.io/tripleomaster',
+        'ceph_namespace': 'docker.io/ceph',
+        'ceph_image': 'daemon',
+        'ceph_tag': 'v3.1.0-stable-3.1-luminous-centos-7-x86_64',
+        'name_prefix': 'centos-binary-',
+        'name_suffix': '',
+        'tag': 'current-tripleo',
+        'neutron_driver': None,
+        'openshift_namespace': 'docker.io/openshift',
+        'openshift_tag': 'v3.10.0',
+        'openshift_base_image': 'origin',
+        'openshift_cockpit_namespace': 'docker.io/cockpit',
+        'openshift_cockpit_image': 'kubernetes',
+        'openshift_cockpit_tag': 'latest',
+        'openshift_etcd_namespace': 'registry.fedoraproject.org/latest',
+        'openshift_etcd_image': 'etcd',
+        'openshift_etcd_tag': 'latest',
+        'openshift_gluster_namespace': 'docker.io/gluster',
+        'openshift_gluster_image': 'gluster-centos',
+        'openshift_gluster_block_image': 'glusterblock-provisioner',
+        'openshift_gluster_tag': 'latest',
+        'openshift_heketi_namespace': 'docker.io/heketi',
+        'openshift_heketi_image': 'heketi',
+        'openshift_heketi_tag': 'latest',
+    }
+}]
 
-CONTAINER_IMAGE_PREPARE_PARAM = None
-
-CONTAINER_IMAGES_DEFAULTS = None
-
-
-def init_prepare_defaults(defaults_file):
-    global CONTAINER_IMAGE_PREPARE_PARAM_STR
-    with open(defaults_file) as f:
-        CONTAINER_IMAGE_PREPARE_PARAM_STR = f.read()
-
-    global CONTAINER_IMAGE_PREPARE_PARAM
-    p = yaml.safe_load(CONTAINER_IMAGE_PREPARE_PARAM_STR)
-    CONTAINER_IMAGE_PREPARE_PARAM = p[
-        'parameter_defaults']['ContainerImagePrepare']
-
-    global CONTAINER_IMAGES_DEFAULTS
-    CONTAINER_IMAGES_DEFAULTS = CONTAINER_IMAGE_PREPARE_PARAM[0]['set']
+CONTAINER_IMAGES_DEFAULTS = CONTAINER_IMAGE_PREPARE_PARAM[0]['set']
 
 DEFAULT_TEMPLATE_FILE = os.path.join(sys.prefix, 'share', 'tripleo-common',
                                      'container-images',
                                      'overcloud_containers.yaml.j2')
 
-DEFAULT_PREPARE_FILE = os.path.join(sys.prefix, 'share', 'tripleo-common',
-                                    'container-images',
-                                    'container_image_prepare_defaults.yaml')
-
-if os.path.isfile(DEFAULT_PREPARE_FILE):
-    init_prepare_defaults(DEFAULT_PREPARE_FILE)
-
 
 def get_enabled_services(environment, roles_data):
     """Build list of enabled services
@@ -105,21 +110,6 @@ def build_service_filter(environment, roles_data):
     return enabled_services
 
 
-def set_neutron_driver(pd, mapping_args):
-    """Set the neutron_driver images variable based on parameters
-
-    :param pd: Parameter defaults from the environment
-    :param mapping_args: Dict to set neutron_driver value on
-    """
-    if not pd or 'NeutronMechanismDrivers' not in pd:
-        return
-    nmd = pd['NeutronMechanismDrivers']
-    if 'opendaylight_v2' in nmd:
-        mapping_args['neutron_driver'] = 'odl'
-    elif 'ovn' in nmd:
-        mapping_args['neutron_driver'] = 'ovn'
-
-
 def container_images_prepare_multi(environment, roles_data, dry_run=False,
                                    cleanup=image_uploader.CLEANUP_FULL):
     """Perform multiple container image prepares and merge result
@@ -145,8 +135,7 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
     service_filter = build_service_filter(environment, roles_data)
 
     for cip_entry in cip:
-        mapping_args = cip_entry.get('set', {})
-        set_neutron_driver(pd, mapping_args)
+        mapping_args = cip_entry.get('set')
         push_destination = cip_entry.get('push_destination')
         # use the configured registry IP as the discovered registry
         # if it is available
@@ -243,6 +232,12 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
     if mapping_args is None:
         mapping_args = {}
 
+    if service_filter:
+        if 'OS::TripleO::Services::OpenDaylightApi' in service_filter:
+            mapping_args['neutron_driver'] = 'odl'
+        elif 'OS::TripleO::Services::OVNController' in service_filter:
+            mapping_args['neutron_driver'] = 'ovn'
+
     def ffunc(entry):
         imagename = entry.get('imagename', '')
         if service_filter is not None:
@@ -434,9 +429,6 @@ class KollaImageBuilder(base.BaseImageManager):
         container_images = self.load_config_files(self.CONTAINER_IMAGES) or []
         container_images.sort(key=lambda i: i.get('imagename'))
         for i in container_images:
-            # Do not attempt to build containers that are not from kolla
-            if not i.get('image_source', '') == 'kolla':
-                continue
             image = self.imagename_to_regex(i.get('imagename'))
             if image:
                 cmd.append(image)
