@@ -206,6 +206,9 @@ class OrchestrationDeployActionTest(base.TestCase):
 
 class DeployStackActionTest(base.TestCase):
 
+    def setUp(self,):
+        super(DeployStackActionTest, self).setUp()
+
     @mock.patch('tripleo_common.actions.deployment.time')
     @mock.patch('heatclient.common.template_utils.'
                 'process_multiple_environments_and_files')
@@ -360,100 +363,6 @@ class DeployStackActionTest(base.TestCase):
             "overcloud-swift-rings", "swift-rings.tar.gz",
             "overcloud-swift-rings/swift-rings.tar.gz-%d" % 1473366264)
 
-    @mock.patch('tripleo_common.actions.deployment.time')
-    @mock.patch('heatclient.common.template_utils.'
-                'process_multiple_environments_and_files')
-    @mock.patch('heatclient.common.template_utils.get_template_contents')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    @mock.patch(
-        'tripleo_common.actions.base.TripleOAction.get_orchestration_client')
-    def test_run_create_failed(
-        self, get_orchestration_client_mock, mock_get_object_client,
-        mock_get_template_contents,
-        mock_process_multiple_environments_and_files, mock_time):
-
-        mock_ctx = mock.MagicMock()
-        # setup swift
-        swift = mock.MagicMock(url="http://test.com")
-        mock_env = yaml.safe_dump({
-            'name': 'overcloud',
-            'temp_environment': 'temp_environment',
-            'template': 'template',
-            'environments': [{u'path': u'environments/test.yaml'}],
-            'parameter_defaults': {'random_existing_data': 'a_value'},
-        }, default_flow_style=False)
-        swift.get_object.side_effect = (
-            ({}, mock_env),
-            ({}, mock_env),
-            swiftexceptions.ClientException('atest2')
-        )
-        mock_get_object_client.return_value = swift
-
-        heat = mock.MagicMock()
-        heat.stacks.get.return_value = None
-        heat.stacks.create.side_effect = heat_exc.HTTPException("Oops")
-        get_orchestration_client_mock.return_value = heat
-
-        mock_get_template_contents.return_value = ({}, {
-            'heat_template_version': '2016-04-30'
-        })
-        mock_process_multiple_environments_and_files.return_value = ({}, {})
-
-        # freeze time at datetime.datetime(2016, 9, 8, 16, 24, 24)
-        mock_time.time.return_value = 1473366264
-
-        action = deployment.DeployStackAction(1, 'overcloud')
-        expected = actions.Result(
-            error="Error during stack creation: ERROR: Oops\n")
-        self.assertEqual(expected, action.run(mock_ctx))
-
-    @mock.patch('tripleo_common.actions.deployment.time')
-    @mock.patch('heatclient.common.template_utils.'
-                'process_multiple_environments_and_files')
-    @mock.patch('heatclient.common.template_utils.get_template_contents')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    @mock.patch(
-        'tripleo_common.actions.base.TripleOAction.get_orchestration_client')
-    def test_run_update_failed(
-        self, get_orchestration_client_mock, mock_get_object_client,
-        mock_get_template_contents,
-        mock_process_multiple_environments_and_files, mock_time):
-
-        mock_ctx = mock.MagicMock()
-        # setup swift
-        swift = mock.MagicMock(url="http://test.com")
-        mock_env = yaml.safe_dump({
-            'name': 'overcloud',
-            'temp_environment': 'temp_environment',
-            'template': 'template',
-            'environments': [{u'path': u'environments/test.yaml'}],
-            'parameter_defaults': {'random_existing_data': 'a_value'},
-        }, default_flow_style=False)
-        swift.get_object.side_effect = (
-            ({}, mock_env),
-            ({}, mock_env),
-            swiftexceptions.ClientException('atest2')
-        )
-        mock_get_object_client.return_value = swift
-
-        heat = mock.MagicMock()
-        heat.stacks.get.return_value = mock.Mock()
-        heat.stacks.update.side_effect = heat_exc.HTTPException("Oops")
-        get_orchestration_client_mock.return_value = heat
-
-        mock_get_template_contents.return_value = ({}, {
-            'heat_template_version': '2016-04-30'
-        })
-        mock_process_multiple_environments_and_files.return_value = ({}, {})
-
-        # freeze time at datetime.datetime(2016, 9, 8, 16, 24, 24)
-        mock_time.time.return_value = 1473366264
-
-        action = deployment.DeployStackAction(1, 'overcloud')
-        expected = actions.Result(
-            error="Error during stack update: ERROR: Oops\n")
-        self.assertEqual(expected, action.run(mock_ctx))
-
     def test_set_tls_parameters_no_ca_found(self):
         action = deployment.DeployStackAction(1, 'overcloud',
                                               skip_deploy_identifier=True)
@@ -594,198 +503,6 @@ class OvercloudRcActionTestCase(base.TestCase):
         self.assertEqual(result, {"overcloudrc": "fake overcloudrc"})
 
 
-class DeploymentStatusActionTest(base.TestCase):
-
-    def setUp(self):
-        super(DeploymentStatusActionTest, self).setUp()
-        self.plan = 'overcloud'
-        self.ctx = mock.MagicMock()
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_object_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_workflow_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_orchestration_client')
-    def test_get_deployment_status(
-            self, heat, mistral, swift):
-
-        mock_stack = mock.Mock()
-        mock_stack.stack_status = 'COMPLETE'
-        heat().stacks.get.return_value = mock_stack
-
-        body = 'deployment_status: DEPLOY_SUCCESS'
-        swift().get_object.return_value = [mock.Mock(), body]
-
-        execution = mock.Mock()
-        execution.updated_at = 1
-        execution.state = 'SUCCESS'
-        execution.output = '{"deployment_status":"DEPLOY_SUCCESS"}'
-        mistral().executions.get.return_value = execution
-        mistral().executions.find.return_value = [execution]
-
-        action = deployment.DeploymentStatusAction(self.plan)
-        result = action.run(self.ctx)
-
-        self.assertEqual(result['stack_status'], 'COMPLETE')
-        self.assertEqual(result['cd_status'], 'SUCCESS')
-        self.assertEqual(result['deployment_status'], 'DEPLOY_SUCCESS')
-        self.assertEqual(result['status_update'], None)
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_object_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_workflow_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_orchestration_client')
-    def test_get_deployment_status_update_failed(
-            self, heat, mistral, swift):
-
-        mock_stack = mock.Mock()
-        mock_stack.stack_status = 'FAILED'
-        heat().stacks.get.return_value = mock_stack
-
-        body = 'deployment_status: DEPLOY_SUCCESS'
-        swift().get_object.return_value = [mock.Mock(), body]
-
-        execution = mock.Mock()
-        execution.updated_at = 1
-        execution.state = 'SUCCESS'
-        execution.output = '{"deployment_status":"DEPLOY_SUCCESS"}'
-        mistral().executions.get.return_value = execution
-        mistral().executions.find.return_value = [execution]
-
-        action = deployment.DeploymentStatusAction(self.plan)
-        result = action.run(self.ctx)
-
-        self.assertEqual(result['stack_status'], 'FAILED')
-        self.assertEqual(result['cd_status'], 'SUCCESS')
-        self.assertEqual(result['deployment_status'], 'DEPLOY_SUCCESS')
-        self.assertEqual(result['status_update'], 'DEPLOY_FAILED')
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_object_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_workflow_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_orchestration_client')
-    def test_get_deployment_status_update_deploying(
-            self, heat, mistral, swift):
-
-        mock_stack = mock.Mock()
-        mock_stack.stack_status = 'IN_PROGRESS'
-        heat().stacks.get.return_value = mock_stack
-
-        body = 'deployment_status: DEPLOY_SUCCESS'
-        swift().get_object.return_value = [mock.Mock(), body]
-
-        execution = mock.Mock()
-        execution.updated_at = 1
-        execution.state = 'SUCCESS'
-        execution.output = '{"deployment_status":"DEPLOY_SUCCESS"}'
-        mistral().executions.get.return_value = execution
-        mistral().executions.find.return_value = [execution]
-
-        action = deployment.DeploymentStatusAction(self.plan)
-        result = action.run(self.ctx)
-
-        self.assertEqual(result['stack_status'], 'IN_PROGRESS')
-        self.assertEqual(result['cd_status'], 'SUCCESS')
-        self.assertEqual(result['deployment_status'], 'DEPLOY_SUCCESS')
-        self.assertEqual(result['status_update'], 'DEPLOYING')
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_object_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_workflow_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_orchestration_client')
-    def test_get_deployment_status_update_success(
-            self, heat, mistral, swift):
-
-        mock_stack = mock.Mock()
-        mock_stack.stack_status = 'COMPLETE'
-        heat().stacks.get.return_value = mock_stack
-
-        body = 'deployment_status: DEPLOYING'
-        swift().get_object.return_value = [mock.Mock(), body]
-
-        execution = mock.Mock()
-        execution.updated_at = 1
-        execution.state = 'SUCCESS'
-        execution.output = '{"deployment_status":"DEPLOY_SUCCESS"}'
-        mistral().executions.get.return_value = execution
-        mistral().executions.find.return_value = [execution]
-
-        action = deployment.DeploymentStatusAction(self.plan)
-        result = action.run(self.ctx)
-
-        self.assertEqual(result['stack_status'], 'COMPLETE')
-        self.assertEqual(result['cd_status'], 'SUCCESS')
-        self.assertEqual(result['deployment_status'], 'DEPLOYING')
-        self.assertEqual(result['status_update'], 'DEPLOY_SUCCESS')
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_object_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_workflow_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_orchestration_client')
-    def test_get_deployment_status_ansible_failed(
-            self, heat, mistral, swift):
-
-        mock_stack = mock.Mock()
-        mock_stack.stack_status = 'COMPLETE'
-        heat().stacks.get.return_value = mock_stack
-
-        body = 'deployment_status: DEPLOYING'
-        swift().get_object.return_value = [mock.Mock(), body]
-
-        execution = mock.Mock()
-        execution.updated_at = 1
-        execution.state = 'SUCCESS'
-        execution.output = '{"deployment_status":"DEPLOY_FAILED"}'
-        mistral().executions.get.return_value = execution
-        mistral().executions.find.return_value = [execution]
-
-        action = deployment.DeploymentStatusAction(self.plan)
-        result = action.run(self.ctx)
-
-        self.assertEqual(result['stack_status'], 'COMPLETE')
-        self.assertEqual(result['cd_status'], 'SUCCESS')
-        self.assertEqual(result['deployment_status'], 'DEPLOYING')
-        self.assertEqual(result['status_update'], 'DEPLOY_FAILED')
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_object_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_workflow_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_orchestration_client')
-    def test_get_deployment_status_no_heat_stack(
-            self, heat, mistral, swift):
-
-        mock_stack = mock.Mock()
-        mock_stack.stack_status = 'COMPLETE'
-        heat().stacks.get.side_effect = heat_exc.HTTPNotFound()
-
-        body = 'deployment_status: DEPLOY_SUCCESS'
-        swift().get_object.return_value = [mock.Mock(), body]
-
-        execution = mock.Mock()
-        execution.updated_at = 1
-        execution.state = 'SUCCESS'
-        execution.output = '{"deployment_status":"DEPLOY_SUCCESS"}'
-        mistral().executions.get.return_value = execution
-        mistral().executions.find.return_value = [execution]
-
-        action = deployment.DeploymentStatusAction(self.plan)
-        result = action.run(self.ctx)
-
-        self.assertEqual(result['status_update'], None)
-        self.assertEqual(result['deployment_status'], None)
-
-
 class DeploymentFailuresActionTest(base.TestCase):
 
     def setUp(self):
