@@ -398,27 +398,45 @@ class ExportPlanActionTest(base.TestCase):
 
         self.ctx = mock.MagicMock()
 
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_service')
     @mock.patch('tripleo_common.utils.tarball.create_tarball')
-    def test_run_success(self, mock_create_tarball):
+    def test_run_success(self,
+                         mock_create_tarball,
+                         mock_get_obj_service):
+
         get_object_mock_calls = [
             mock.call(self.plan, tf) for tf in self.template_files
         ]
 
+        swift_service = mock.MagicMock()
+        swift_service.upload.return_value = ([
+            {'success': True},
+        ])
+        mock_get_obj_service.return_value = swift_service
+
         action = plan.ExportPlanAction(self.plan, self.delete_after,
                                        self.exports_container)
         action.run(self.ctx)
 
         self.swift.get_container.assert_called_once_with(self.plan)
-        self.swift.put_container.assert_called_once_with('plan-exports')
         self.swift.get_object.assert_has_calls(
             get_object_mock_calls, any_order=True)
-        self.swift.put_object.assert_called_once()
+        swift_service.upload.assert_called_once()
         mock_create_tarball.assert_called_once()
 
-    def test_run_container_does_not_exist(self):
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_service')
+    def test_run_container_does_not_exist(self,
+                                          mock_get_obj_service):
+
         self.swift.get_container.side_effect = swiftexceptions.ClientException(
             self.plan)
 
+        swift_service = mock.MagicMock()
+        swift_service.delete.return_value = ([
+            {'success': True},
+        ])
+        mock_get_obj_service.return_value = swift_service
+
         action = plan.ExportPlanAction(self.plan, self.delete_after,
                                        self.exports_container)
         result = action.run(self.ctx)
@@ -426,10 +444,20 @@ class ExportPlanActionTest(base.TestCase):
         error = "Error attempting an operation on container: %s" % self.plan
         self.assertIn(error, result.error)
 
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_service')
     @mock.patch('tripleo_common.utils.tarball.create_tarball')
-    def test_run_error_creating_tarball(self, mock_create_tarball):
+    def test_run_error_creating_tarball(self,
+                                        mock_create_tarball,
+                                        mock_get_obj_service):
+
         mock_create_tarball.side_effect = processutils.ProcessExecutionError
 
+        swift_service = mock.MagicMock()
+        swift_service.delete.return_value = ([
+            {'success': True},
+        ])
+        mock_get_obj_service.return_value = swift_service
+
         action = plan.ExportPlanAction(self.plan, self.delete_after,
                                        self.exports_container)
         result = action.run(self.ctx)
@@ -587,3 +615,47 @@ class GatherRolesActionTest(base.TestCase):
         # assert that a role was loaded from self.current_roles
         self.assertTrue(result.data['gathered_roles'],
                         [SAMPLE_ROLE_OBJ, self.available_role])
+
+
+class RemoveNoopDeployStepActionTest(base.TestCase):
+
+    def setUp(self):
+        super(RemoveNoopDeployStepActionTest, self).setUp()
+        self.container = 'overcloud'
+        self.ctx = mock.MagicMock()
+        self.heat = mock.MagicMock()
+        self.swift = mock.MagicMock()
+        self.rr_before = {
+            'OS::TripleO::Foo': 'bar.yaml',
+            'OS::TripleO::DeploymentSteps': 'OS::Heat::None',
+        }
+        self.rr_after = {
+            'OS::TripleO::Foo': 'bar.yaml',
+        }
+
+    @mock.patch('tripleo_common.actions.plan.plan_utils')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
+    @mock.patch(
+        'tripleo_common.actions.base.TripleOAction.get_orchestration_client')
+    def test_roles_gathered(self, mock_orch_client, mock_obj_client,
+                            mock_plan_utils):
+        mock_obj_client.return_value = self.swift
+        mock_orch_client.return_value = self.heat
+        mock_plan_utils.get_env.return_value = {
+            'name': self.container,
+            'resource_registry': self.rr_before,
+        }
+        mock_plan_utils.get_user_env.return_value = {
+            'resource_registry': self.rr_before,
+        }
+        action = plan.RemoveNoopDeployStepAction(self.container)
+        action.run(self.ctx)
+
+        mock_plan_utils.put_env.assert_called_with(
+            self.swift,
+            {
+                'name': self.container,
+                'resource_registry': self.rr_after,
+            })
+        mock_plan_utils.put_user_env.assert_called_with(
+            self.swift, self.container, {'resource_registry': self.rr_after})
