@@ -30,12 +30,12 @@ from tripleo_common.tests.image import fakes
 
 filedata = six.u(
     """container_images:
-    - imagename: docker.io/tripleorocky/heat-docker-agents-centos:latest
+    - imagename: docker.io/tripleomaster/heat-docker-agents-centos:latest
       push_destination: localhost:8787
-    - imagename: docker.io/tripleorocky/centos-binary-nova-compute:liberty
+    - imagename: docker.io/tripleomaster/centos-binary-nova-compute:liberty
       push_destination: localhost:8787
-    - imagename: docker.io/tripleorocky/centos-binary-nova-libvirt:liberty
-    - imagename: docker.io/tripleorocky/image-with-missing-tag
+    - imagename: docker.io/tripleomaster/centos-binary-nova-libvirt:liberty
+    - imagename: docker.io/tripleomaster/image-with-missing-tag
       push_destination: localhost:8787
 """)
 
@@ -50,10 +50,10 @@ class TestImageUploadManager(base.TestCase):
     @mock.patch('tripleo_common.image.base.open',
                 mock.mock_open(read_data=filedata), create=True)
     @mock.patch('tripleo_common.image.image_uploader.'
-                'DockerImageUploader.is_insecure_registry',
+                'BaseImageUploader.is_insecure_registry',
                 return_value=True)
     @mock.patch('tripleo_common.image.image_uploader.'
-                'DockerImageUploader._images_match',
+                'BaseImageUploader._images_match',
                 return_value=False)
     @mock.patch('os.path.isfile', return_value=True)
     @mock.patch('fcntl.ioctl', side_effect=Exception)
@@ -76,22 +76,22 @@ class TestImageUploadManager(base.TestCase):
 
         dockerc = mockdocker.return_value
         dockerc.remove_image.assert_has_calls([
-            mock.call('192.0.2.0:8787/tripleorocky'
+            mock.call('192.0.2.0:8787/tripleomaster'
                       '/centos-binary-nova-libvirt:liberty'),
-            mock.call('docker.io/tripleorocky'
+            mock.call('docker.io/tripleomaster'
                       '/centos-binary-nova-compute:liberty'),
-            mock.call('docker.io/tripleorocky'
+            mock.call('docker.io/tripleomaster'
                       '/centos-binary-nova-libvirt:liberty'),
-            mock.call('docker.io/tripleorocky'
+            mock.call('docker.io/tripleomaster'
                       '/heat-docker-agents-centos:latest'),
-            mock.call('docker.io/tripleorocky'
+            mock.call('docker.io/tripleomaster'
                       '/image-with-missing-tag:latest'),
 
-            mock.call('localhost:8787/tripleorocky'
+            mock.call('localhost:8787/tripleomaster'
                       '/centos-binary-nova-compute:liberty'),
-            mock.call('localhost:8787/tripleorocky'
+            mock.call('localhost:8787/tripleomaster'
                       '/heat-docker-agents-centos:latest'),
-            mock.call('localhost:8787/tripleorocky/'
+            mock.call('localhost:8787/tripleomaster/'
                       'image-with-missing-tag:latest'),
         ])
 
@@ -159,284 +159,12 @@ class TestImageUploader(base.TestCase):
                           'unknown')
 
 
-class TestDockerImageUploader(base.TestCase):
+class TestBaseImageUploader(base.TestCase):
 
     def setUp(self):
-        super(TestDockerImageUploader, self).setUp()
-        self.uploader = image_uploader.DockerImageUploader()
-        self.patcher = mock.patch('tripleo_common.image.image_uploader.Client')
-        self.dockermock = self.patcher.start()
-
-    def tearDown(self):
-        super(TestDockerImageUploader, self).tearDown()
-        self.patcher.stop()
-
-    @mock.patch('subprocess.Popen')
-    def test_upload_image(self, mock_popen):
-        result1 = {
-            'Digest': 'a'
-        }
-        result2 = {
-            'Digest': 'b'
-        }
-        mock_process = mock.Mock()
-        mock_process.communicate.side_effect = [
-            (json.dumps(result1), ''),
-            (json.dumps(result2), ''),
-        ]
-
-        mock_process.returncode = 0
-        mock_popen.return_value = mock_process
-
-        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
-        tag = 'latest'
-        push_destination = 'localhost:8787'
-        push_image = 'localhost:8787/tripleorocky/heat-docker-agents-centos'
-
-        self.assertEqual(
-            ['docker.io/tripleorocky/heat-docker-agents-centos:latest',
-             'localhost:8787/tripleorocky/heat-docker-agents-centos:latest'],
-            self.uploader.upload_image(
-                image + ':' + tag,
-                None,
-                push_destination,
-                set(),
-                None,
-                None,
-                None,
-                False,
-                'full'
-            )
-        )
-
-        self.dockermock.assert_called_once_with(
-            base_url='unix://var/run/docker.sock', version='auto')
-
-        self.dockermock.return_value.pull.assert_called_once_with(
-            image, tag=tag, stream=True)
-        self.dockermock.return_value.tag.assert_called_once_with(
-            image=image + ':' + tag,
-            repository=push_image,
-            tag=tag, force=True)
-        self.dockermock.return_value.push.assert_called_once_with(
-            push_image,
-            tag=tag, stream=True)
-
-    @mock.patch('subprocess.Popen')
-    def test_upload_image_missing_tag(self, mock_popen):
-        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
-        expected_tag = 'latest'
-        push_destination = 'localhost:8787'
-        push_image = 'localhost:8787/tripleorocky/heat-docker-agents-centos'
-
-        self.uploader.upload_image(image,
-                                   None,
-                                   push_destination,
-                                   set(),
-                                   None,
-                                   None,
-                                   None,
-                                   False,
-                                   'full')
-
-        self.dockermock.assert_called_once_with(
-            base_url='unix://var/run/docker.sock', version='auto')
-
-        self.dockermock.return_value.pull.assert_called_once_with(
-            image, tag=expected_tag, stream=True)
-        self.dockermock.return_value.tag.assert_called_once_with(
-            image=image + ':' + expected_tag,
-            repository=push_image,
-            tag=expected_tag, force=True)
-        self.dockermock.return_value.push.assert_called_once_with(
-            push_image,
-            tag=expected_tag, stream=True)
-
-    @mock.patch('subprocess.Popen')
-    def test_upload_image_existing(self, mock_popen):
-        result = {
-            'Digest': 'a'
-        }
-        mock_process = mock.Mock()
-        mock_process.communicate.return_value = (json.dumps(result), '')
-        mock_process.returncode = 0
-        mock_popen.return_value = mock_process
-        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
-        tag = 'latest'
-        push_destination = 'localhost:8787'
-
-        self.assertEqual(
-            [],
-            self.uploader.upload_image(
-                image + ':' + tag,
-                None,
-                push_destination,
-                set(),
-                None,
-                None,
-                None,
-                False,
-                'full'
-            )
-        )
-
-        # both digests are the same, no pull/push
-        self.dockermock.assert_not_called()
-        self.dockermock.return_value.pull.assert_not_called()
-        self.dockermock.return_value.tag.assert_not_called()
-        self.dockermock.return_value.push.assert_not_called()
-
-    @mock.patch('subprocess.Popen')
-    @mock.patch('tripleo_common.actions.'
-                'ansible.AnsiblePlaybookAction', autospec=True)
-    def test_modify_upload_image(self, mock_ansible, mock_popen):
-        mock_process = mock.Mock()
-        mock_process.communicate.return_value = (
-            '', 'FATA[0000] Error reading manifest: manifest unknown')
-
-        mock_process.returncode = 1
-        mock_popen.return_value = mock_process
-
-        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
-        tag = 'latest'
-        append_tag = 'modify-123'
-        push_destination = 'localhost:8787'
-        push_image = 'localhost:8787/tripleorocky/heat-docker-agents-centos'
-        playbook = [{
-            'tasks': [{
-                'import_role': {
-                    'name': 'add-foo-plugin'
-                },
-                'name': 'Import role add-foo-plugin',
-                'vars': {
-                    'target_image': '%s:%s' % (push_image, tag),
-                    'modified_append_tag': append_tag,
-                    'source_image': '%s:%s' % (image, tag),
-                    'foo_version': '1.0.1'
-                }
-            }],
-            'hosts': 'localhost'
-        }]
-
-        # test response for a partial cleanup
-        self.assertEqual(
-            ['docker.io/tripleorocky/heat-docker-agents-centos:latest'],
-            self.uploader.upload_image(
-                image + ':' + tag,
-                None,
-                push_destination,
-                set(),
-                append_tag,
-                'add-foo-plugin',
-                {'foo_version': '1.0.1'},
-                False,
-                'partial'
-            )
-        )
-
-        self.dockermock.assert_called_once_with(
-            base_url='unix://var/run/docker.sock', version='auto')
-
-        self.dockermock.return_value.pull.assert_called_once_with(
-            image, tag=tag, stream=True)
-        mock_ansible.assert_called_once_with(
-            playbook=playbook, work_dir=mock.ANY)
-        self.dockermock.return_value.tag.assert_not_called()
-        self.dockermock.return_value.push.assert_called_once_with(
-            push_image,
-            tag=tag + append_tag,
-            stream=True)
-
-    @mock.patch('subprocess.Popen')
-    @mock.patch('tripleo_common.actions.'
-                'ansible.AnsiblePlaybookAction', autospec=True)
-    def test_modify_image_failed(self, mock_ansible, mock_popen):
-        mock_process = mock.Mock()
-        mock_process.communicate.return_value = ('', 'manifest unknown')
-
-        mock_process.returncode = 1
-        mock_popen.return_value = mock_process
-
-        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
-        tag = 'latest'
-        append_tag = 'modify-123'
-        push_destination = 'localhost:8787'
-        error = processutils.ProcessExecutionError(
-            '', 'ouch', -1, 'ansible-playbook')
-        mock_ansible.return_value.run.side_effect = error
-
-        self.assertRaises(
-            processutils.ProcessExecutionError,
-            self.uploader.upload_image,
-            image + ':' + tag, None, push_destination, set(), append_tag,
-            'add-foo-plugin', {'foo_version': '1.0.1'}, False, 'full'
-        )
-
-        self.dockermock.assert_called_once_with(
-            base_url='unix://var/run/docker.sock', version='auto')
-
-        self.dockermock.return_value.pull.assert_called_once_with(
-            image, tag=tag, stream=True)
-        self.dockermock.return_value.tag.assert_not_called()
-        self.dockermock.return_value.push.assert_not_called()
-
-    @mock.patch('subprocess.Popen')
-    @mock.patch('tripleo_common.actions.'
-                'ansible.AnsiblePlaybookAction', autospec=True)
-    def test_modify_upload_image_dry_run(self, mock_ansible, mock_popen):
-        mock_process = mock.Mock()
-        mock_popen.return_value = mock_process
-
-        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
-        tag = 'latest'
-        append_tag = 'modify-123'
-        push_destination = 'localhost:8787'
-
-        result = self.uploader.upload_image(
-            image + ':' + tag,
-            None,
-            push_destination,
-            set(),
-            append_tag,
-            'add-foo-plugin',
-            {'foo_version': '1.0.1'},
-            True,
-            'full'
-        )
-
-        self.dockermock.assert_not_called()
-        mock_ansible.assert_not_called()
-        mock_process.communicate.assert_not_called()
-        self.assertEqual([], result)
-
-    @mock.patch('tripleo_common.image.image_uploader.'
-                'DockerImageUploader._inspect')
-    @mock.patch('tripleo_common.actions.'
-                'ansible.AnsiblePlaybookAction', autospec=True)
-    def test_modify_image_existing(self, mock_ansible, mock_inspect):
-        mock_inspect.return_value = {'Digest': 'a'}
-
-        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
-        tag = 'latest'
-        append_tag = 'modify-123'
-        push_destination = 'localhost:8787'
-
-        result = self.uploader.upload_image(
-            image + ':' + tag,
-            None,
-            push_destination,
-            set(),
-            append_tag,
-            'add-foo-plugin',
-            {'foo_version': '1.0.1'},
-            False,
-            'full'
-        )
-
-        self.dockermock.assert_not_called()
-        mock_ansible.assert_not_called()
-
-        self.assertEqual([], result)
+        super(TestBaseImageUploader, self).setUp()
+        self.uploader = image_uploader.BaseImageUploader()
+        self.uploader._inspect.retry.sleep = mock.Mock()
 
     @mock.patch('requests.get')
     def test_is_insecure_registry_known(self, mock_get):
@@ -633,90 +361,8 @@ class TestDockerImageUploader(base.TestCase):
                 ('docker.io/t/baz', 'rdo_release', set())
             ])
 
-    @mock.patch('tenacity.wait.wait_random_exponential.__call__')
-    def test_pull_retry(self, mock_wait):
-        mock_wait.return_value = 0
-        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
-
-        dockerc = self.dockermock.return_value
-        dockerc.pull.side_effect = [
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"status": "done"}']
-        ]
-        self.uploader._pull(dockerc, image)
-
-        self.assertEqual(dockerc.pull.call_count, 5)
-        dockerc.pull.assert_has_calls([
-            mock.call(image, tag=None, stream=True)
-        ])
-
-    @mock.patch('tenacity.wait.wait_random_exponential.__call__')
-    def test_pull_retry_failure(self, mock_wait):
-        mock_wait.return_value = 0
-        image = 'docker.io/tripleorocky/heat-docker-agents-centos'
-
-        dockerc = self.dockermock.return_value
-        dockerc.pull.side_effect = [
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-        ]
-        self.assertRaises(urllib3.exceptions.ReadTimeoutError,
-                          self.uploader._pull, dockerc, image)
-
-        self.assertEqual(dockerc.pull.call_count, 5)
-        dockerc.pull.assert_has_calls([
-            mock.call(image, tag=None, stream=True)
-        ])
-
-    @mock.patch('tenacity.wait.wait_random_exponential.__call__')
-    def test_push_retry(self, mock_wait):
-        mock_wait.return_value = 0
-        image = 'docker.io/tripleoupstream/heat-docker-agents-centos'
-
-        dockerc = self.dockermock.return_value
-        dockerc.push.side_effect = [
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"status": "done"}']
-        ]
-        self.uploader._push(dockerc, image)
-
-        self.assertEqual(dockerc.push.call_count, 5)
-        dockerc.push.assert_has_calls([
-            mock.call(image, tag=None, stream=True)
-        ])
-
-    @mock.patch('tenacity.wait.wait_random_exponential.__call__')
-    def test_push_retry_failure(self, mock_wait):
-        mock_wait.return_value = 0
-        image = 'docker.io/tripleoupstream/heat-docker-agents-centos'
-
-        dockerc = self.dockermock.return_value
-        dockerc.push.side_effect = [
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-        ]
-        self.assertRaises(ImageUploaderException,
-                          self.uploader._push, dockerc, image)
-
-        self.assertEqual(dockerc.push.call_count, 5)
-        dockerc.push.assert_has_calls([
-            mock.call(image, tag=None, stream=True)
-        ])
-
     @mock.patch('tripleo_common.image.image_uploader.'
-                'DockerImageUploader._inspect')
+                'BaseImageUploader._inspect')
     def test_images_match(self, mock_inspect):
         mock_inspect.side_effect = [{'Digest': 'a'}, {'Digest': 'b'}]
         self.assertFalse(self.uploader._images_match('foo', 'bar', set()))
@@ -735,3 +381,362 @@ class TestDockerImageUploader(base.TestCase):
 
         mock_inspect.side_effect = ImageUploaderException()
         self.assertFalse(self.uploader._images_match('foo', 'bar', set()))
+
+
+class TestDockerImageUploader(base.TestCase):
+
+    def setUp(self):
+        super(TestDockerImageUploader, self).setUp()
+        self.uploader = image_uploader.DockerImageUploader()
+        self.uploader._push.retry.sleep = mock.Mock()
+        self.uploader._pull.retry.sleep = mock.Mock()
+        self.uploader._inspect.retry.sleep = mock.Mock()
+
+        self.patcher = mock.patch('tripleo_common.image.image_uploader.Client')
+        self.dockermock = self.patcher.start()
+
+    def tearDown(self):
+        super(TestDockerImageUploader, self).tearDown()
+        self.patcher.stop()
+
+    @mock.patch('subprocess.Popen')
+    def test_upload_image(self, mock_popen):
+        result1 = {
+            'Digest': 'a'
+        }
+        result2 = {
+            'Digest': 'b'
+        }
+        mock_process = mock.Mock()
+        mock_process.communicate.side_effect = [
+            (json.dumps(result1), ''),
+            (json.dumps(result2), ''),
+        ]
+
+        mock_process.returncode = 0
+        mock_popen.return_value = mock_process
+
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        tag = 'latest'
+        push_destination = 'localhost:8787'
+        push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+
+        self.assertEqual(
+            ['docker.io/tripleomaster/heat-docker-agents-centos:latest',
+             'localhost:8787/tripleomaster/heat-docker-agents-centos:latest'],
+            self.uploader.upload_image(
+                image + ':' + tag,
+                None,
+                push_destination,
+                set(),
+                None,
+                None,
+                None,
+                False,
+                'full'
+            )
+        )
+
+        self.dockermock.assert_called_once_with(
+            base_url='unix://var/run/docker.sock', version='auto')
+
+        self.dockermock.return_value.pull.assert_called_once_with(
+            image, tag=tag, stream=True)
+        self.dockermock.return_value.tag.assert_called_once_with(
+            image=image + ':' + tag,
+            repository=push_image,
+            tag=tag, force=True)
+        self.dockermock.return_value.push.assert_called_once_with(
+            push_image,
+            tag=tag, stream=True)
+
+    @mock.patch('subprocess.Popen')
+    def test_upload_image_missing_tag(self, mock_popen):
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        expected_tag = 'latest'
+        push_destination = 'localhost:8787'
+        push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+
+        self.uploader.upload_image(image,
+                                   None,
+                                   push_destination,
+                                   set(),
+                                   None,
+                                   None,
+                                   None,
+                                   False,
+                                   'full')
+
+        self.dockermock.assert_called_once_with(
+            base_url='unix://var/run/docker.sock', version='auto')
+
+        self.dockermock.return_value.pull.assert_called_once_with(
+            image, tag=expected_tag, stream=True)
+        self.dockermock.return_value.tag.assert_called_once_with(
+            image=image + ':' + expected_tag,
+            repository=push_image,
+            tag=expected_tag, force=True)
+        self.dockermock.return_value.push.assert_called_once_with(
+            push_image,
+            tag=expected_tag, stream=True)
+
+    @mock.patch('subprocess.Popen')
+    def test_upload_image_existing(self, mock_popen):
+        result = {
+            'Digest': 'a'
+        }
+        mock_process = mock.Mock()
+        mock_process.communicate.return_value = (json.dumps(result), '')
+        mock_process.returncode = 0
+        mock_popen.return_value = mock_process
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        tag = 'latest'
+        push_destination = 'localhost:8787'
+
+        self.assertEqual(
+            [],
+            self.uploader.upload_image(
+                image + ':' + tag,
+                None,
+                push_destination,
+                set(),
+                None,
+                None,
+                None,
+                False,
+                'full'
+            )
+        )
+
+        # both digests are the same, no pull/push
+        self.dockermock.assert_not_called()
+        self.dockermock.return_value.pull.assert_not_called()
+        self.dockermock.return_value.tag.assert_not_called()
+        self.dockermock.return_value.push.assert_not_called()
+
+    @mock.patch('subprocess.Popen')
+    @mock.patch('tripleo_common.actions.'
+                'ansible.AnsiblePlaybookAction', autospec=True)
+    def test_modify_upload_image(self, mock_ansible, mock_popen):
+        mock_process = mock.Mock()
+        mock_process.communicate.return_value = (
+            '', 'FATA[0000] Error reading manifest: manifest unknown')
+
+        mock_process.returncode = 1
+        mock_popen.return_value = mock_process
+        mock_ansible.return_value.run.return_value = {}
+
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        tag = 'latest'
+        append_tag = 'modify-123'
+        push_destination = 'localhost:8787'
+        push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        playbook = [{
+            'tasks': [{
+                'import_role': {
+                    'name': 'add-foo-plugin'
+                },
+                'name': 'Import role add-foo-plugin',
+                'vars': {
+                    'target_image': '%s:%s' % (push_image, tag),
+                    'modified_append_tag': append_tag,
+                    'source_image': '%s:%s' % (image, tag),
+                    'foo_version': '1.0.1'
+                }
+            }],
+            'hosts': 'localhost'
+        }]
+
+        # test response for a partial cleanup
+        self.assertEqual(
+            ['docker.io/tripleomaster/heat-docker-agents-centos:latest'],
+            self.uploader.upload_image(
+                image + ':' + tag,
+                None,
+                push_destination,
+                set(),
+                append_tag,
+                'add-foo-plugin',
+                {'foo_version': '1.0.1'},
+                False,
+                'partial'
+            )
+        )
+
+        self.dockermock.assert_called_once_with(
+            base_url='unix://var/run/docker.sock', version='auto')
+
+        self.dockermock.return_value.pull.assert_called_once_with(
+            image, tag=tag, stream=True)
+        mock_ansible.assert_called_once_with(
+            playbook=playbook, work_dir=mock.ANY, verbosity=3)
+        self.dockermock.return_value.tag.assert_not_called()
+        self.dockermock.return_value.push.assert_called_once_with(
+            push_image,
+            tag=tag + append_tag,
+            stream=True)
+
+    @mock.patch('subprocess.Popen')
+    @mock.patch('tripleo_common.actions.'
+                'ansible.AnsiblePlaybookAction', autospec=True)
+    def test_modify_image_failed(self, mock_ansible, mock_popen):
+        mock_process = mock.Mock()
+        mock_process.communicate.return_value = ('', 'manifest unknown')
+
+        mock_process.returncode = 1
+        mock_popen.return_value = mock_process
+
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        tag = 'latest'
+        append_tag = 'modify-123'
+        push_destination = 'localhost:8787'
+        error = processutils.ProcessExecutionError(
+            '', 'ouch', -1, 'ansible-playbook')
+        mock_ansible.return_value.run.side_effect = error
+
+        self.assertRaises(
+            ImageUploaderException,
+            self.uploader.upload_image,
+            image + ':' + tag, None, push_destination, set(), append_tag,
+            'add-foo-plugin', {'foo_version': '1.0.1'}, False, 'full'
+        )
+
+        self.dockermock.assert_called_once_with(
+            base_url='unix://var/run/docker.sock', version='auto')
+
+        self.dockermock.return_value.pull.assert_called_once_with(
+            image, tag=tag, stream=True)
+        self.dockermock.return_value.tag.assert_not_called()
+        self.dockermock.return_value.push.assert_not_called()
+
+    @mock.patch('subprocess.Popen')
+    @mock.patch('tripleo_common.actions.'
+                'ansible.AnsiblePlaybookAction', autospec=True)
+    def test_modify_upload_image_dry_run(self, mock_ansible, mock_popen):
+        mock_process = mock.Mock()
+        mock_popen.return_value = mock_process
+
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        tag = 'latest'
+        append_tag = 'modify-123'
+        push_destination = 'localhost:8787'
+
+        result = self.uploader.upload_image(
+            image + ':' + tag,
+            None,
+            push_destination,
+            set(),
+            append_tag,
+            'add-foo-plugin',
+            {'foo_version': '1.0.1'},
+            True,
+            'full'
+        )
+
+        self.dockermock.assert_not_called()
+        mock_ansible.assert_not_called()
+        mock_process.communicate.assert_not_called()
+        self.assertEqual([], result)
+
+    @mock.patch('tripleo_common.image.image_uploader.'
+                'BaseImageUploader._inspect')
+    @mock.patch('tripleo_common.actions.'
+                'ansible.AnsiblePlaybookAction', autospec=True)
+    def test_modify_image_existing(self, mock_ansible, mock_inspect):
+        mock_inspect.return_value = {'Digest': 'a'}
+
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        tag = 'latest'
+        append_tag = 'modify-123'
+        push_destination = 'localhost:8787'
+
+        result = self.uploader.upload_image(
+            image + ':' + tag,
+            None,
+            push_destination,
+            set(),
+            append_tag,
+            'add-foo-plugin',
+            {'foo_version': '1.0.1'},
+            False,
+            'full'
+        )
+
+        self.dockermock.assert_not_called()
+        mock_ansible.assert_not_called()
+
+        self.assertEqual([], result)
+
+    def test_pull_retry(self):
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+
+        dockerc = self.dockermock.return_value
+        dockerc.pull.side_effect = [
+            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
+            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
+            ['{"error": "ouch"}'],
+            ['{"error": "ouch"}'],
+            ['{"status": "done"}']
+        ]
+        self.uploader._pull(dockerc, image)
+
+        self.assertEqual(dockerc.pull.call_count, 5)
+        dockerc.pull.assert_has_calls([
+            mock.call(image, tag=None, stream=True)
+        ])
+
+    def test_pull_retry_failure(self):
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+
+        dockerc = self.dockermock.return_value
+        dockerc.pull.side_effect = [
+            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
+            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
+            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
+            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
+            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
+        ]
+        self.assertRaises(urllib3.exceptions.ReadTimeoutError,
+                          self.uploader._pull, dockerc, image)
+
+        self.assertEqual(dockerc.pull.call_count, 5)
+        dockerc.pull.assert_has_calls([
+            mock.call(image, tag=None, stream=True)
+        ])
+
+    def test_push_retry(self):
+        image = 'docker.io/tripleoupstream/heat-docker-agents-centos'
+
+        dockerc = self.dockermock.return_value
+        dockerc.push.side_effect = [
+            ['{"error": "ouch"}'],
+            ['{"error": "ouch"}'],
+            ['{"error": "ouch"}'],
+            ['{"error": "ouch"}'],
+            ['{"status": "done"}']
+        ]
+        self.uploader._push(dockerc, image)
+
+        self.assertEqual(dockerc.push.call_count, 5)
+        dockerc.push.assert_has_calls([
+            mock.call(image, tag=None, stream=True)
+        ])
+
+    def test_push_retry_failure(self):
+        image = 'docker.io/tripleoupstream/heat-docker-agents-centos'
+
+        dockerc = self.dockermock.return_value
+        dockerc.push.side_effect = [
+            ['{"error": "ouch"}'],
+            ['{"error": "ouch"}'],
+            ['{"error": "ouch"}'],
+            ['{"error": "ouch"}'],
+            ['{"error": "ouch"}'],
+        ]
+        self.assertRaises(ImageUploaderException,
+                          self.uploader._push, dockerc, image)
+
+        self.assertEqual(dockerc.push.call_count, 5)
+        dockerc.push.assert_has_calls([
+            mock.call(image, tag=None, stream=True)
+        ])
