@@ -33,48 +33,28 @@ TEMPLATE_PATH = os.path.join(os.path.dirname(__file__),
                              'overcloud_containers.yaml.j2')
 
 
-DEFAULTS_PATH = os.path.join(os.path.dirname(__file__),
-                             '..', '..', '..', 'container-images',
-                             'container_image_prepare_defaults.yaml')
-kb.init_prepare_defaults(DEFAULTS_PATH)
-
-
 filedata = six.u("""container_images:
-- imagename: docker.io/tripleorocky/heat-docker-agents-centos:latest
-  image_source: kolla
+- imagename: docker.io/tripleomaster/heat-docker-agents-centos:latest
   push_destination: localhost:8787
-- imagename: docker.io/tripleorocky/centos-binary-nova-compute:liberty
-  image_source: kolla
+- imagename: docker.io/tripleomaster/centos-binary-nova-compute:liberty
   uploader: docker
   push_destination: localhost:8787
-- imagename: docker.io/tripleorocky/centos-binary-nova-libvirt:liberty
-  image_source: kolla
+- imagename: docker.io/tripleomaster/centos-binary-nova-libvirt:liberty
   uploader: docker
-- imagename: docker.io/tripleorocky/image-with-missing-tag
-  image_source: kolla
-  push_destination: localhost:8787
-- imagename: docker.io/tripleorocky/skip-build
-  image_source: foo
+- imagename: docker.io/tripleomaster/image-with-missing-tag
   push_destination: localhost:8787
 """)
 
 template_filedata = six.u("""
 container_images_template:
 - imagename: "{{namespace}}/heat-docker-agents-centos:latest"
-  image_source: kolla
   push_destination: "{{push_destination}}"
 - imagename: "{{namespace}}/{{name_prefix}}nova-compute{{name_suffix}}:{{tag}}"
-  image_source: kolla
   uploader: "docker"
   push_destination: "{{push_destination}}"
 - imagename: "{{namespace}}/{{name_prefix}}nova-libvirt{{name_suffix}}:{{tag}}"
-  image_source: kolla
   uploader: "docker"
 - imagename: "{{namespace}}/image-with-missing-tag"
-  image_source: kolla
-  push_destination: "{{push_destination}}"
-- imagename: "{{namespace}}/skip-build"
-  image_source: foo
   push_destination: "{{push_destination}}"
 """)
 
@@ -184,17 +164,17 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
         self.assertEqual(
             {
-                'namespace': 'docker.io/tripleorocky',
+                'namespace': 'docker.io/tripleomaster',
                 'ceph_namespace': 'docker.io/ceph',
                 'ceph_image': 'daemon',
-                'ceph_tag': 'v3.2.1-stable-3.2-luminous-centos-7-x86_64',
+                'ceph_tag': 'v3.1.0-stable-3.1-luminous-centos-7-x86_64',
                 'name_prefix': 'centos-binary-',
                 'name_suffix': '',
                 'tag': 'current-tripleo',
                 'neutron_driver': None,
                 'openshift_namespace': 'docker.io/openshift',
-                'openshift_tag': 'v3.11.0',
-                'openshift_prefix': 'origin',
+                'openshift_tag': 'v3.10.0',
+                'openshift_base_image': 'origin',
                 'openshift_cockpit_namespace': 'docker.io/cockpit',
                 'openshift_cockpit_image': 'kubernetes',
                 'openshift_cockpit_tag': 'latest',
@@ -209,59 +189,23 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'openshift_heketi_namespace': 'docker.io/heketi',
                 'openshift_heketi_image': 'heketi',
                 'openshift_heketi_tag': 'latest',
-                'openshift_asb_namespace': 'docker.io/ansibleplaybookbundle',
-                'openshift_asb_tag': 'latest',
-                'openshift_cluster_monitoring_namespace':
-                    'docker.io/tripleorocky',
-                'openshift_cluster_monitoring_image':
-                    'coreos-cluster-monitoring-operator',
-                'openshift_cluster_monitoring_tag': 'v0.1.1',
-                'openshift_configmap_reload_namespace':
-                    'docker.io/tripleorocky',
-                'openshift_configmap_reload_image': 'coreos-configmap-reload',
-                'openshift_configmap_reload_tag': 'v0.0.1',
-                'openshift_prometheus_operator_namespace':
-                    'docker.io/tripleorocky',
-                'openshift_prometheus_operator_image':
-                    'coreos-prometheus-operator',
-                'openshift_prometheus_operator_tag': 'v0.23.2',
-                'openshift_prometheus_config_reload_namespace':
-                    'docker.io/tripleorocky',
-                'openshift_prometheus_config_reload_image':
-                    'coreos-prometheus-config-reloader',
-                'openshift_prometheus_config_reload_tag': 'v0.23.2',
-                'openshift_prometheus_tag': 'v2.3.2',
-                'openshift_prometheus_alertmanager_tag': 'v0.15.2',
-                'openshift_prometheus_node_exporter_tag': 'v0.16.0',
-                'openshift_oauth_proxy_tag': 'v1.1.0',
-                'openshift_kube_rbac_proxy_namespace':
-                    'docker.io/tripleorocky',
-                'openshift_kube_rbac_proxy_image': 'coreos-kube-rbac-proxy',
-                'openshift_kube_rbac_proxy_tag': 'v0.3.1',
-                'openshift_kube_state_metrics_namespace':
-                    'docker.io/tripleorocky',
-                'openshift_kube_state_metrics_image':
-                    'coreos-kube-state-metrics',
-                'openshift_kube_state_metrics_tag': 'v1.3.1',
-                'openshift_grafana_namespace': 'docker.io/grafana',
-                'openshift_grafana_tag': '5.2.1',
             },
             builder.container_images_template_inputs()
         )
 
         self.assertEqual(
             {
-                'namespace': '192.0.2.0:5000/tripleorocky',
+                'namespace': '192.0.2.0:5000/tripleomaster',
                 'ceph_namespace': 'docker.io/cephh',
                 'ceph_image': 'ceph-daemon',
                 'ceph_tag': 'latest',
                 'name_prefix': 'prefix-',
                 'name_suffix': '-suffix',
-                'tag': 'rocky',
+                'tag': 'master',
                 'neutron_driver': 'ovn',
                 'openshift_namespace': 'docker.io/openshift3',
-                'openshift_tag': 'v3.11.0',
-                'openshift_prefix': 'ose',
+                'openshift_tag': 'v3.10.0',
+                'openshift_base_image': 'ose',
                 'openshift_cockpit_namespace': 'docker.io/openshift-cockpit',
                 'openshift_cockpit_image': 'cockpit',
                 'openshift_cockpit_tag': 'cockpit-tag',
@@ -269,65 +213,28 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'openshift_etcd_image': 'openshift-etcd',
                 'openshift_etcd_tag': 'etcd-tag',
                 'openshift_gluster_namespace':
-                    'registry.access.redhat.com/rhgs3',
+                'registry.access.redhat.com/rhgs3',
                 'openshift_gluster_image': 'rhgs-server-rhel7',
                 'openshift_gluster_block_image':
-                    'rhgs-gluster-block-prov-rhel7',
+                'rhgs-gluster-block-prov-rhel7',
                 'openshift_gluster_tag': 'gluster-tag',
                 'openshift_heketi_namespace':
-                    'registry.access.redhat.com/rhgs3',
+                'registry.access.redhat.com/rhgs3',
                 'openshift_heketi_image': 'rhgs-volmanager-rhel7',
                 'openshift_heketi_tag': 'heketi-tag',
-                'openshift_asb_namespace':
-                    'registry.access.redhat.com/openshift3',
-                'openshift_asb_tag': 'v3.11',
-                'openshift_cluster_monitoring_namespace':
-                    'registry.access.redhat.com/openshift3',
-                'openshift_cluster_monitoring_image':
-                    'ose-cluster-monitoring-operator',
-                'openshift_cluster_monitoring_tag': 'v3.11',
-                'openshift_configmap_reload_namespace':
-                    'registry.access.redhat.com/openshift3',
-                'openshift_configmap_reload_image': 'ose-configmap-reloader',
-                'openshift_configmap_reload_tag': 'v3.11',
-                'openshift_prometheus_operator_namespace':
-                    'registry.access.redhat.com/openshift3',
-                'openshift_prometheus_operator_image':
-                    'ose-prometheus-operator',
-                'openshift_prometheus_operator_tag': 'v3.11',
-                'openshift_prometheus_config_reload_namespace':
-                    'registry.access.redhat.com/openshift3',
-                'openshift_prometheus_config_reload_image':
-                    'ose-prometheus-config-reloader',
-                'openshift_prometheus_config_reload_tag': 'v3.11',
-                'openshift_prometheus_tag': 'v3.11',
-                'openshift_prometheus_alertmanager_tag': 'v3.11',
-                'openshift_prometheus_node_exporter_tag': 'v3.11',
-                'openshift_oauth_proxy_tag': 'v3.11',
-                'openshift_kube_rbac_proxy_namespace':
-                    'registry.access.redhat.com/openshift3',
-                'openshift_kube_rbac_proxy_image': 'ose-kube-rbac-proxy',
-                'openshift_kube_rbac_proxy_tag': 'v3.11',
-                'openshift_kube_state_metrics_namespace':
-                    'registry.access.redhat.com/openshift3',
-                'openshift_kube_state_metrics_image': 'ose-kube-state-metrics',
-                'openshift_kube_state_metrics_tag': 'v3.11',
-                'openshift_grafana_namespace':
-                    'registry.access.redhat.com/openshift3',
-                'openshift_grafana_tag': 'v3.11',
             },
             builder.container_images_template_inputs(
-                namespace='192.0.2.0:5000/tripleorocky',
+                namespace='192.0.2.0:5000/tripleomaster',
                 ceph_namespace='docker.io/cephh',
                 ceph_image='ceph-daemon',
                 ceph_tag='latest',
                 name_prefix='prefix',
                 name_suffix='suffix',
-                tag='rocky',
+                tag='master',
                 neutron_driver='ovn',
                 openshift_namespace='docker.io/openshift3',
-                openshift_tag='v3.11.0',
-                openshift_prefix='ose',
+                openshift_tag='v3.10.0',
+                openshift_base_image='ose',
                 openshift_cockpit_namespace='docker.io/openshift-cockpit',
                 openshift_cockpit_image='cockpit',
                 openshift_cockpit_tag='cockpit-tag',
@@ -341,43 +248,6 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 openshift_heketi_namespace='registry.access.redhat.com/rhgs3',
                 openshift_heketi_image='rhgs-volmanager-rhel7',
                 openshift_heketi_tag='heketi-tag',
-                openshift_asb_namespace='registry.'
-                    'access.redhat.com/openshift3',
-                openshift_asb_tag='v3.11',
-                openshift_cluster_monitoring_namespace='registry.'
-                    'access.redhat.com/openshift3',
-                openshift_cluster_monitoring_image='ose-'
-                    'cluster-monitoring-operator',
-                openshift_cluster_monitoring_tag='v3.11',
-                openshift_configmap_reload_namespace='registry.'
-                    'access.redhat.com/openshift3',
-                openshift_configmap_reload_image='ose-configmap-reloader',
-                openshift_configmap_reload_tag='v3.11',
-                openshift_prometheus_operator_namespace='registry.'
-                    'access.redhat.com/openshift3',
-                openshift_prometheus_operator_image='ose-'
-                    'prometheus-operator',
-                openshift_prometheus_operator_tag='v3.11',
-                openshift_prometheus_config_reload_namespace='registry.'
-                    'access.redhat.com/openshift3',
-                openshift_prometheus_config_reload_image='ose-'
-                    'prometheus-config-reloader',
-                openshift_prometheus_config_reload_tag='v3.11',
-                openshift_prometheus_tag='v3.11',
-                openshift_prometheus_alertmanager_tag='v3.11',
-                openshift_prometheus_node_exporter_tag='v3.11',
-                openshift_oauth_proxy_tag='v3.11',
-                openshift_kube_rbac_proxy_namespace='registry.'
-                    'access.redhat.com/openshift3',
-                openshift_kube_rbac_proxy_image='ose-kube-rbac-proxy',
-                openshift_kube_rbac_proxy_tag='v3.11',
-                openshift_kube_state_metrics_namespace='registry.'
-                    'access.redhat.com/openshift3',
-                openshift_kube_state_metrics_image='ose-kube-state-metrics',
-                openshift_kube_state_metrics_tag='v3.11',
-                openshift_grafana_namespace='registry.'
-                    'access.redhat.com/openshift3',
-                openshift_grafana_tag='v3.11',
             )
         )
 
@@ -399,24 +269,17 @@ class TestKollaImageBuilderTemplate(base.TestCase):
             tag='liberty'
         )
         container_images = [{
-            'image_source': 'kolla',
-            'imagename': 'docker.io/tripleorocky/'
+            'imagename': 'docker.io/tripleomaster/'
                          'centos-binary-nova-compute:liberty',
             'push_destination': 'localhost:8787',
             'uploader': 'docker'
         }, {
-            'image_source': 'kolla',
-            'imagename': 'docker.io/tripleorocky/'
+            'imagename': 'docker.io/tripleomaster/'
                          'centos-binary-nova-libvirt:liberty',
             'push_destination': 'localhost:8787',
             'uploader': 'docker'
         }, {
-            'image_source': 'kolla',
-            'imagename': 'docker.io/tripleorocky/image-with-missing-tag',
-            'push_destination': 'localhost:8787'
-        }, {
-            'image_source': 'foo',
-            'imagename': 'docker.io/tripleorocky/skip-build',
+            'imagename': 'docker.io/tripleomaster/image-with-missing-tag',
             'push_destination': 'localhost:8787'
         }]
         self.assertEqual(container_images, result)
@@ -458,32 +321,23 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
     def test_container_images_yaml_in_sync(self):
         remove_images = [
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-base:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-opendaylight:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-northd:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'controller:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             remove_images=remove_images)
@@ -491,29 +345,21 @@ class TestKollaImageBuilderTemplate(base.TestCase):
     def test_container_images_yaml_in_sync_for_odl(self):
         # remove neutron-server image reference from overcloud_containers.yaml
         remove_images = [
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-base:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-northd:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'controller:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='odl', remove_images=remove_images)
@@ -521,14 +367,11 @@ class TestKollaImageBuilderTemplate(base.TestCase):
     def test_container_images_yaml_in_sync_for_ovn(self):
         # remove neutron-server image reference from overcloud_containers.yaml
         remove_images = [
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
-            {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleorocky/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-opendaylight:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='ovn', remove_images=remove_images)
@@ -588,8 +431,7 @@ class TestPrepare(base.TestCase):
     def test_prepare_simple(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
-                {'image_source': 'kolla',
-                 'imagename': '192.0.2.0:8787/t/p-nova-compute:l'}
+                {'imagename': '192.0.2.0:8787/t/p-nova-compute:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNovaComputeImage': '192.0.2.0:8787/t/p-nova-compute:l',
@@ -615,8 +457,7 @@ class TestPrepare(base.TestCase):
     def test_prepare_includes(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
-                {'image_source': 'kolla',
-                 'imagename': '192.0.2.0:8787/t/p-nova-libvirt:l'}
+                {'imagename': '192.0.2.0:8787/t/p-nova-libvirt:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNovaLibvirtImage': '192.0.2.0:8787/t/p-nova-libvirt:l'
@@ -640,8 +481,7 @@ class TestPrepare(base.TestCase):
         # assert same result as includes only. includes trumps excludes
         self.assertEqual({
             'container_images.yaml': [
-                {'image_source': 'kolla',
-                 'imagename': '192.0.2.0:8787/t/p-nova-libvirt:l'}
+                {'imagename': '192.0.2.0:8787/t/p-nova-libvirt:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNovaLibvirtImage': '192.0.2.0:8787/t/p-nova-libvirt:l'
@@ -665,7 +505,6 @@ class TestPrepare(base.TestCase):
     def test_prepare_push_dest(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [{
-                'image_source': 'kolla',
                 'imagename': 'docker.io/t/p-nova-api:l',
                 'push_destination': '192.0.2.0:8787',
             }],
@@ -700,7 +539,6 @@ class TestPrepare(base.TestCase):
         mock_gur.return_value = '192.0.2.0:8787'
         self.assertEqual({
             'container_images.yaml': [{
-                'image_source': 'kolla',
                 'imagename': 'docker.io/t/p-nova-api:l',
                 'push_destination': '192.0.2.0:8787',
             }],
@@ -733,7 +571,6 @@ class TestPrepare(base.TestCase):
     def test_prepare_ceph(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [{
-                'image_source': 'ceph',
                 'imagename': '192.0.2.0:8787/t/ceph:l',
             }],
             'environments/containers-default-parameters.yaml': {
@@ -756,8 +593,7 @@ class TestPrepare(base.TestCase):
     def test_prepare_neutron_driver_default(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
-                {'image_source': 'kolla',
-                 'imagename': 't/p-neutron-server:l'}
+                {'imagename': 't/p-neutron-server:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNeutronApiImage': 't/p-neutron-server:l',
@@ -767,15 +603,12 @@ class TestPrepare(base.TestCase):
                 template_file=TEMPLATE_PATH,
                 output_env_file=constants.CONTAINER_DEFAULTS_ENVIRONMENT,
                 output_images_file='container_images.yaml',
-                service_filter=[
-                    'OS::TripleO::Services::NeutronServer'
-                ],
+                service_filter=['OS::TripleO::Services::NeutronServer'],
                 mapping_args={
                     'namespace': 't',
                     'name_prefix': 'p',
                     'name_suffix': '',
                     'tag': 'l',
-                    'neutron_driver': None
                 }
             )
         )
@@ -784,10 +617,8 @@ class TestPrepare(base.TestCase):
     def test_prepare_neutron_driver_ovn(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
-                {'image_source': 'kolla',
-                 'imagename': 't/p-neutron-server-ovn:l'},
-                {'image_source': 'kolla',
-                 'imagename': 't/p-ovn-controller:l'}
+                {'imagename': 't/p-neutron-server-ovn:l'},
+                {'imagename': 't/p-ovn-controller:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNeutronApiImage': 't/p-neutron-server-ovn:l',
@@ -808,7 +639,6 @@ class TestPrepare(base.TestCase):
                     'name_prefix': 'p',
                     'name_suffix': '',
                     'tag': 'l',
-                    'neutron_driver': 'ovn'
                 }
             )
         )
@@ -817,10 +647,8 @@ class TestPrepare(base.TestCase):
     def test_prepare_neutron_driver_odl(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
-                {'image_source': 'kolla',
-                 'imagename': 't/neutron-server-opendaylight:l'},
-                {'image_source': 'kolla',
-                 'imagename': 't/opendaylight:l'}
+                {'imagename': 't/neutron-server-opendaylight:l'},
+                {'imagename': 't/opendaylight:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNeutronApiImage': 't/neutron-server-opendaylight:l',
@@ -841,7 +669,6 @@ class TestPrepare(base.TestCase):
                     'name_prefix': '',
                     'name_suffix': '',
                     'tag': 'l',
-                    'neutron_driver': 'odl'
                 }
             )
         )
@@ -1178,32 +1005,3 @@ class TestPrepare(base.TestCase):
             },
             image_params
         )
-
-    def test_set_neutron_driver(self):
-        mapping_args = {}
-        kb.set_neutron_driver(None, mapping_args)
-        self.assertNotIn('neutron_driver', mapping_args)
-
-        mapping_args = {}
-        kb.set_neutron_driver({}, mapping_args)
-        self.assertNotIn('neutron_driver', mapping_args)
-
-        mapping_args = {}
-        kb.set_neutron_driver(
-            {'NeutronMechanismDrivers': ['sriovnicswitch', 'openvswitch']},
-            mapping_args
-        )
-        self.assertNotIn('neutron_driver', mapping_args)
-
-        mapping_args = {}
-        kb.set_neutron_driver(
-            {'NeutronMechanismDrivers': ['ovn']},
-            mapping_args
-        )
-        self.assertEqual('ovn', mapping_args['neutron_driver'])
-        mapping_args = {}
-        kb.set_neutron_driver(
-            {'NeutronMechanismDrivers': ['sriovnicswitch', 'opendaylight_v2']},
-            mapping_args
-        )
-        self.assertEqual('odl', mapping_args['neutron_driver'])
