@@ -72,7 +72,7 @@ class Config(object):
             if server_id in v:
                 return k
 
-    def get_deployment_resource_id(self, deployment):
+    def get_config_dict(self, deployment):
         if '/' in deployment.attributes['value']['deployment']:
             deployment_stack_id = \
                 deployment.attributes['value']['deployment'].split('/')[-1]
@@ -82,9 +82,6 @@ class Config(object):
         else:
             deployment_resource_id = \
                 deployment.attributes['value']['deployment']
-        return deployment_resource_id
-
-    def get_config_dict(self, deployment_resource_id):
         deployment_rsrc = self.client.software_deployments.get(
             deployment_resource_id)
         config = self.client.software_configs.get(
@@ -153,9 +150,7 @@ class Config(object):
     def snapshot_config_dir(self, repo, commit_message):
         if repo.is_dirty(untracked_files=True):
             self.log.info('Snapshotting {}'.format(repo.working_dir))
-            # Use repo.git.add directly as repo.index.add defaults to forcing
-            # commit of ignored files, which we don't want.
-            repo.git.add('.')
+            repo.index.add('*')
             commit = repo.index.commit(commit_message)
             self.log.info('Created commit {}'.format(commit.hexsha))
         else:
@@ -201,7 +196,6 @@ class Config(object):
         # Get role data:
         role_data = self.stack_outputs.get('RoleData', {})
         role_group_vars = self.stack_outputs.get('RoleGroupVars', {})
-        allnodes_vars = self.stack_outputs.get('AllNodesConfig', {})
         for role_name, role in six.iteritems(role_data):
             role_path = os.path.join(config_dir, role_name)
             self._mkdir(role_path)
@@ -259,30 +253,8 @@ class Config(object):
         server_roles = {}
 
         for deployment in deployments_data:
-            # Check if the deployment value is the resource name. If that's the
-            # case, Heat did not create a physical_resource_id for this
-            # deployment since it does not trigger on this stack action. Such
-            # as a deployment that only triggers on DELETE, but this is a stack
-            # create. If that's the case, just skip this deployment, otherwise
-            # it will result in a Not found error if we try and query the
-            # deployment API for this deployment.
-            dep_value_resource_name = deployment.attributes[
-                'value'].get('deployment') == 'TripleOSoftwareDeployment'
-
-            # if not check the physical_resource_id
-            if not dep_value_resource_name:
-                deployment_resource_id = self.get_deployment_resource_id(
-                    deployment)
-
-            if dep_value_resource_name or not deployment_resource_id:
-                warnings.warn('Skipping deployment %s because it has no '
-                              'valid uuid (physical_resource_id) '
-                              'associated.' %
-                              deployment.physical_resource_id)
-                continue
-
             server_id = deployment.attributes['value']['server']
-            config_dict = self.get_config_dict(deployment_resource_id)
+            config_dict = self.get_config_dict(deployment)
 
             # deployment_name should be set via the name property on the
             # Deployment resources in the templates, however, if it's None
@@ -315,10 +287,9 @@ class Config(object):
                 deployment_stack = self.client.stacks.get(
                     deployment_stack_id, resolve_outputs=False)
                 parent_stack = deployment_stack.parent
-                grandparent_stack = self.client.stacks.get(
-                    parent_stack, resolve_outputs=False).parent
                 resources = self.client.resources.list(
-                    grandparent_stack,
+                    name,
+                    nested_depth=constants.NESTED_DEPTH,
                     filters=dict(physical_resource_id=parent_stack))
                 if not resources:
                     message = "The deployment resource grandparent name could" \
@@ -382,13 +353,6 @@ class Config(object):
 
         group_vars_dir = os.path.join(config_dir, 'group_vars')
         self._mkdir(group_vars_dir)
-        # Write allnodes_vars to 'overcloud' group as it doesn't apply
-        # to the undercloud, and 'overcloud' is the inventory group
-        # for all overcloud nodes, regardless of the --stack name.
-        filepath = os.path.join(group_vars_dir, 'overcloud.yaml')
-        with self._open_file(filepath) as vars_file:
-            yaml.safe_dump(allnodes_vars, vars_file, default_flow_style=False)
-
         host_vars_dir = os.path.join(config_dir, 'host_vars')
         self._mkdir(host_vars_dir)
 
@@ -433,12 +397,12 @@ class Config(object):
                                "config-download." % d['deployment_name'])
                     warnings.warn(message, DeprecationWarning)
 
-                with open(deployment_path, 'wb') as f:
+                with open(deployment_path, 'w') as f:
                     template_data = deployment_template.render(
                         deployment=d,
                         server_id=server_ids[server])
                     self.validate_config(template_data, deployment_path)
-                    f.write(template_data.encode('utf-8'))
+                    f.write(template_data)
 
         for role, deployments in role_deployment_names.items():
             group_var_role_path = os.path.join(group_vars_dir, role)
